@@ -1,6 +1,10 @@
 """
+The pythonbible-parser library.
+
 pythonbible-parser is a Python library for parsing Bible texts in various formats
 and convert them into a format for easy and efficient use in Python.
 """
 
-__version__ = "0.0.1"
+from __future__ import annotations
+
+__version__ = "0.0.4"
